@@ -56,9 +56,10 @@ class Cvt_Int(Cvt):
     cmd = "interface", None
 
     def remove(self, old, int_name):
-        # only remove the interface if it's not physical
+        # default the interface, if it's physical (as we can't remove
+        # physical interfaces)
         if is_int_physical(int_name):
-            return
+            return "default interface " + int_name
 
         return "no interface " + int_name
 
