@@ -566,7 +566,7 @@ _differ = difflib.Differ()
 
 
 
-def explain_diffs(old, new, indent="", prefix=""):
+def explain_diffs(old, new, indent="", prefix="", to_str_func=None):
     """This function compares two lists (typically an access-list or
     prefix-list) and returns the commands to create the new list but
     interspersed with comments that explain the differences.
@@ -587,10 +587,27 @@ def explain_diffs(old, new, indent="", prefix=""):
     If either of the two lists supplied are None, an empty list is
     assumed, either removing or adding all the entries.
 
+    The optional 'to_str_func' argument is used to convert list elements
+    to strings, in advance of the comparison.  This is useful when the
+    data in the lists is stored in a structured form (such as a tuple or
+    dictionary).  The argument takes a function which is passed the
+    element and must return a string.
+
     The return value is a list of lines these explaining comments
     inserted.  The lines without comments will create the new list.
     """
 
+    # if either old or new missing, default them to the empty list
+    old = old or []
+    new = new or []
+
+    # if we have a string conversion function, apply that and convert
+    # the result to a list (it would otherwise be a generator which does
+    # not have a length and can only be iterated through)
+    if to_str_func:
+        old = list(to_str_func(i) for i in old)
+        new = list(to_str_func(i) for i in new)
+
     # initialise the returned list
     r = []
 
@@ -602,7 +619,7 @@ def explain_diffs(old, new, indent="", prefix=""):
     # difflib.Differ.compare, which adds a character at the start,
     # explaining if a line is added, removed or the same, followed by
     # a space
-    for line in _differ.compare(old or [], new or []):
+    for line in _differ.compare(old, new):
         op, text = line[0], line[2:]
 
         if op == " ":
